@@ -15,12 +15,21 @@
 // specific language governing permissions and limitations
 // under the License.
 
+#[cfg(feature = "services-dropbox")]
 mod backend;
-mod builder;
+#[cfg(feature = "services-dropbox")]
 mod core;
+#[cfg(feature = "services-dropbox")]
 mod error;
+#[cfg(feature = "services-dropbox")]
 mod lister;
+#[cfg(feature = "services-dropbox")]
 mod writer;
 
+#[cfg(feature = "services-dropbox")]
+mod builder;
+#[cfg(feature = "services-dropbox")]
 pub use builder::DropboxBuilder as Dropbox;
-pub use builder::DropboxConfig;
+
+mod config;
+pub use config::DropboxConfig;
